// This is only for the doc
#ifdef DOC

/*?class WObject
Every widget inherits from the class \typ{WObject}.
?*/

/*?
The basic cast constructor for C++ widgets.
?*/
WObject :: WObject (Widget w)
{
	widget = w;
}

/*?
The copy constructor for C++ widgets.
?*/
WObject :: WObject (WObject& w)
{
	widget = w.widget;
}

/*?
The basic constructor for C++ widgets. Used by every subclasses.
?*/
WObject :: WObject (WComposite& super,  WidgetClass c, const char* name, ArgList args, Cardinal card)
{
	widget = XtCreateWidget (name, c, super.widget, args, card);
}

/*?
The cast operator, to get a C widget from a C++ widget.
?*/
WObject ::  operator Widget () const
{
	return widget;
}

/*?
Return the class of the widget.
?*/
WidgetClass
WObject :: WidgetClass Class () const
{
	return XtClass (widget);
}

/*?
The \fun{XtRealize} function.
?*/
void
WObject :: Realize () const
{
	XtRealizeWidget (widget);
}

/*?
The \fun{XtUnrealizeWidget} function.
?*/
void
WObject :: Unrealize () const
{
	XtUnrealizeWidget (widget);
}

/*?
The \fun{XtIsRealized} function.
?*/
Boolean
WObject :: IsRealized () const
{
	return XtIsRealized (widget);
}

/*?
The \fun{XtDestroyWidget} function.
{\em Beware to delete the C++ object after calling this method}.
?*/
void
WObject :: Destroy () const
{
	XtDestroyWidget (widget);
}

/*?
Get one resource value. Equivalent of \fun{XtGetValues} with one
\typ{XtArg} record.
?*/
Arg&
WObject :: Get (Arg& a) const
{
	XtGetValues (widget, &a, 1);
	return a;
}

/*?nodoc?*/
Arg&
WObject :: _Get (Arg& a) const
{
	XtGetValues (widget, &a, 1);
	return a;
}

/*?nextdoc?*/
void
WObject :: Get (ArgList a, Cardinal c) const
{
	XtGetValues (widget, a, c);
}

/*?
The \fun{XtGetValues} function.
?*/
void
WObject :: Get (WArgList& w) const
{
}

/*?
Set one resource value. Equivalent of \fun{XtSetValues} with one
\typ{XtArg} record.
?*/
Arg&
WObject :: Set (Arg& a) const
{
	XtSetValues (widget, &a, 1);
	return a;
}

/*?nodoc?*/
Arg&
WObject :: _Set (Arg& a) const
{
	XtSetValues (widget, &a, 1);
	return a;
}

/*?nextdoc?*/
void
WObject :: Set (ArgList a, Cardinal c) const
{ 
	XtSetValues (widget, a, c);
}

/*?
The \fun{XtSetValues} function.
?*/
void
WObject :: Set (WArgList& w) const
{ 
}

/*?
The \fun{XtAddCallback} function.
?*/
void
WObject :: AddCallback (const char* name, XtCallbackProc proc, caddr_t closure) const
{
	XtAddCallback (widget, name, proc, closure);
}

/*?
The \fun{XtRemoveCallback} function.
?*/
void
WObject :: RemoveCallback (const char* name, XtCallbackProc proc, caddr_t closure) const
{
	XtRemoveCallback (widget, name, proc, closure);
}

/*?
The \fun{XtAddCallbacks} function.
?*/
void
WObject :: AddCallbacks (const char* name, XtCallbackList callbacks) const
{
	XtAddCallbacks (widget, name, callbacks);
}

/*?
The \fun{XtRemoveCallbacks} function.
?*/
void
WObject :: RemoveCallbacks (const char* name, XtCallbackList callbacks) const
{
	XtRemoveCallbacks (widget, name, callbacks);
}

/*?
The \fun{XtRemoveAllCallbacks} function.
?*/
void
WObject :: RemoveAllCallbacks (const char* name) const
{
	XtRemoveAllCallbacks (widget, name);
}

/*?
The \fun{XtCallCallbacks} function.
?*/
void
WObject :: CallCallbacks (const char* name, caddr_t call_data) const
{
	XtCallCallbacks (widget, name, call_data);
}

/*?nodoc?*/
WCallback*
WObject :: SetCallback (const char* name, WWL* obj, WWL_FUN fun) const
{
	return new WCallback (widget, name, obj, fun);
}
#endif
