/*
 *	WWL		(c) Copyright LRI 1990
 *
 *	C++ Callbacks
 *
 *	$Id: wcallback.cc,v 1.4 91/02/26 16:27:35 jdf Exp $
 *	$CurLog$        (Log at end)
 */

#include <X11/Intrinsic.h>
#include "wcallback.h"

// ---------------- the callback

static void
cbWwl (Widget widget, caddr_t closure, caddr_t client_data)
{
	((WCallback*) closure) -> Call (client_data);
}

/*?class WWL
?*/

/*?nodoc?*/
WWL :: WWL ()
{
	cbList = 0;
}

/*?
Remove all callbacks set on this object.
?*/
WWL :: ~WWL ()
{
	WCallback* ncb;
	for (WCallback* pcb = cbList; pcb; pcb = ncb) {
		ncb = pcb->next;
		pcb->object = 0;	// avoid calling RemoveCb from ~WCallback
		delete pcb;
	}
	cbList = 0;
}

/*?
Add a member callback to this object.
{\tt o->AddCb(cb)} is identical to {\tt cb->Obj(o)}.
?*/
void
WWL :: AddCb (WCallback* cb)
{
	if (cb->object)
		cb->object->RemoveCb (cb);
	cb->next = cbList;
	cb->object = this;
	cbList = cb;
}

/*?
Remove a member callback
from this object. Return True if the callback was found, else False.
Note that the callback can be then added to this or another object.
?*/
Boolean
WWL :: RemoveCb (WCallback* cb)
{
	if (! cb)
		return True;
	if (cb == cbList) {
		cbList = cb->next;
		cb->next = 0;
		cb->object = 0;
		return True;
	}
	WCallback* ncb = 0;
	for (WCallback* pcb = cbList; pcb; pcb = ncb) {
		ncb = pcb->next;
		if (ncb == cb) {
			pcb->next = ncb->next;
			cb->next = 0;
			cb->object = 0;
			return True;
		}
	}
	return False;
}

/*?class WCallback
?*/


/*?
Create a new member callback, for the callback list named \var{n} of
the widget \var{w}. The member function to call is {\tt o->f}.
If \var{o} is null, the member callback is created but not activated.
It can be activated later with \fun{Obj(WWL*)} or \fun{WWL::AddCb}.
?*/
WCallback :: WCallback (Widget w, const char* n, WWL* o, WWL_FUN f)
{
	next = 0;
	widget = w;
	name = n;
	object = 0;
	fun = f;
	XtAddCallback (widget, name, (XtCallbackProc)cbWwl, (caddr_t) this);
	if (o)
		o->AddCb (this);
}


/*?
Remove the callback from the widget callback list,
and from the associated object, if any.
?*/
WCallback :: ~WCallback ()
{
	XtRemoveCallback (widget, name, (XtCallbackProc)cbWwl, (caddr_t) this);
	if (object)
		object->RemoveCb (this);
}

#ifdef DOC
/*?
Get the member function of this callback.
?*/
WWL_FUN
WCallback :: Fun ()
{ return fun; }

/*?
Set the member function of this callback.
?*/
void
WCallback :: Fun (WWL_FUN f)
{ fun = f; }

/*?
Get the object of this callback.
?*/
WWL*
WCallback :: Obj ()
{
}

/*?
Set the object of this callback.
?*/
void
WCallback :: Obj (WWL* o)
{
}

/*?
Retreive the callback information.
This is valid only from the body of the member callback.
?*/
caddr_t
WCallback :: Data ()
{
}

/*?
Retreive the widget the callback is associated with.
?*/
Widget
WCallback :: GetWidget ()
{
}
#endif


/*?nodoc?*/
void
WCallback :: Call (caddr_t client_data)
{
	if (object) {
		data = client_data;
		(object->*fun) (this);
	}
}

/*
 *	$Log:	wcallback.cc,v $
 *	Revision 1.4  91/02/26  16:27:35  jdf
 *	Added some cast for CC
 *	
 *	Revision 1.2  90/08/13  19:36:20  mbl
 *	added RCS header
 *	
 */
